==> openx-2.5.69-beta.tar.bz2: openx-2.5.69-beta/lib/max/language/es/userlog.lang.php <==
<?php

/*
+---------------------------------------------------------------------------+
| OpenX v2.5                                                                |
| ==========                                                                |
|                                                                           |
| Copyright (c) 2003-2008 OpenX Limited                                     |
| For contact details, see: http://www.openx.org/                           |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: userlog.lang.php 21310 2008-06-12 11:12:19Z david.keen@openx.org $
*/

// Set translation strings

$GLOBALS['strDeliveryEngine']				= "Motor de entrega";
$GLOBALS['strMaintenance']					= "Mantenimiento";
$GLOBALS['strAdministrator']				= "Administrador";


$GLOBALS['strUserlog'][phpAds_actionAdvertiserReportMailed] = "Informe para anunciante {id} enviado por e-mail";
$GLOBALS['strUserlog'][phpAds_actionPublisherReportMailed] = "Informe para p&aacute;gina web {id} enviado por e-mail";
$GLOBALS['strUserlog'][phpAds_actionWarningMailed] = "Aviso de desactivaci&oacute;n de campa&ntilde;a {id} enviado v&iacute;a e-mail";
$GLOBALS['strUserlog'][phpAds_actionDeactivationMailed] = "Notificaci&oacute;n de la desactivaci&oacute;n de la campa&ntilde;a {id} enviada por e-mail";
$GLOBALS['strUserlog'][phpAds_actionPriorityCalculation] = "Prioridades recalculadas";
$GLOBALS['strUserlog'][phpAds_actionPriorityAutoTargeting] = "Objetivos de Campaña recalculados";
$GLOBALS['strUserlog'][phpAds_actionDeactiveCampaign] = "Campaña {id} desactivada";
$GLOBALS['strUserlog'][phpAds_actionActiveCampaign] = "Campaña {id} activada";
$GLOBALS['strUserlog'][phpAds_actionAutoClean] = "Autolimpieza de la base de datos";




// Note: new translatiosn not found in original lang files but found in CSV
$GLOBALS['strUserlog']['hpAds_actionBatchStatistic'] = "Estad&iacute;sticas compiladas";
$GLOBALS['strAudit'] = "Log Audit";
$GLOBALS['strLogging'] = "Grabando";
$GLOBALS['strDebugLog'] = "Log Debug";
$GLOBALS['strEvent'] = "Evento";
$GLOBALS['strTimestamp'] = "Timestamp";
$GLOBALS['strDeleted'] = "borrado";
$GLOBALS['strInserted'] = "insertado";
$GLOBALS['strUpdated'] = "actualizado";
$GLOBALS['strInsert'] = "Insertar";
$GLOBALS['strUpdate'] = "Actualizar";
$GLOBALS['strHas'] = "tiene";
$GLOBALS['strFilters'] = "Filtros";
$GLOBALS['strAdvertiser'] = "Anunciante";
$GLOBALS['strPublisher'] = "P&aacute;gina web";
$GLOBALS['strType'] = "Tipo";
$GLOBALS['strParameter'] = "Par&aacute;metro";
$GLOBALS['strValue'] = "Valor";
$GLOBALS['strDetailedView'] = "Vista detallada";
$GLOBALS['strReturnAuditTrail'] = "Volver a Audit Trail";
$GLOBALS['strAuditTrail'] = "Audit Trail";
$GLOBALS['strMaintenanceLog'] = "Log de mantenimiento";
$GLOBALS['strAuditResultsNotFound'] = "No hay eventos que concuerden con el criterio de selecci&oacute;n";
$GLOBALS['strCollectedAllEvents'] = "Todos los eventos";
$GLOBALS['strClear'] = "Limpiar";
?>

==> openx-2.7.27-beta.tar.bz2: openx-2.7.27-beta/lib/max/language/es/userlog.lang.php <==
<?php

/*
+---------------------------------------------------------------------------+
| OpenX v2.7                                                                |
| ==========                                                                |
|                                                                           |
| Copyright (c) 2003-2008 OpenX Limited                                     |
| For contact details, see: http://www.openx.org/                           |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: userlog.lang.php 29689 2008-12-03 16:30:29Z andrew.hill $
*/

// Set translation strings

$GLOBALS['strDeliveryEngine']				= "Motor de entrega";
$GLOBALS['strMaintenance']					= "Mantenimiento";
$GLOBALS['strAdministrator']				= "Administrador";


$GLOBALS['strUserlog'][phpAds_actionAdvertiserReportMailed] = "Informe para anunciante {id} enviado por e-mail";
$GLOBALS['strUserlog'][phpAds_actionPublisherReportMailed] = "Informe para página web {id} enviado por e-mail";
$GLOBALS['strUserlog'][phpAds_actionWarningMailed] = "Aviso de desactivación de campaña {id} enviado vía e-mail";
$GLOBALS['strUserlog'][phpAds_actionDeactivationMailed] = "Notificación de la desactivación de la campaña {id} enviada por e-mail";
$GLOBALS['strUserlog'][phpAds_actionPriorityCalculation] = "Prioridades recalculadas";
$GLOBALS['strUserlog'][phpAds_actionPriorityAutoTargeting] = "Objetivos de Campaña recalculados";
$GLOBALS['strUserlog'][phpAds_actionDeactiveCampaign] = "Campaña {id} desactivada";
$GLOBALS['strUserlog'][phpAds_actionActiveCampaign] = "Campaña {id} activada";
$GLOBALS['strUserlog'][phpAds_actionAutoClean] = "Autolimpieza de la base de datos";




// Note: new translatiosn not found in original lang files but found in CSV
$GLOBALS['strUserlog']['hpAds_actionBatchStatistic'] = "Estad&iacute;sticas compiladas";
$GLOBALS['strAudit'] = "Auditar Registro";
$GLOBALS['strLogging'] = "Grabando";
$GLOBALS['strDebugLog'] = "Depurar Registro";
$GLOBALS['strEvent'] = "Evento";
$GLOBALS['strTimestamp'] = "Timestamp";
$GLOBALS['strDeleted'] = "borrado";
$GLOBALS['strInserted'] = "insertado";
$GLOBALS['strUpdated'] = "actualizado";
$GLOBALS['strInsert'] = "Insertar";
$GLOBALS['strUpdate'] = "Actualizar";
$GLOBALS['strHas'] = "tiene";
$GLOBALS['strFilters'] = "Filtros";
$GLOBALS['strAdvertiser'] = "Anunciante";
$GLOBALS['strPublisher'] = "Página web";
$GLOBALS['strType'] = "Tipo";
$GLOBALS['strParameter'] = "Parámetro";
$GLOBALS['strValue'] = "Valor";
$GLOBALS['strDetailedView'] = "Vista detallada";
$GLOBALS['strReturnAuditTrail'] = "Volver a Audit Trail";
$GLOBALS['strAuditTrail'] = "Audit Trail";
$GLOBALS['strMaintenanceLog'] = "Registro de mantenimiento";
$GLOBALS['strAuditResultsNotFound'] = "No hay eventos que concuerden con el criterio de selección";
$GLOBALS['strCollectedAllEvents'] = "Todos los eventos";
$GLOBALS['strClear'] = "Limpiar";


// Note: New translations not found in original lang files but found in CSV
$GLOBALS['strUserlog'][phpAds_actionBatchStatistics] = "Estadísticas compiladas";
$GLOBALS['strUserlog'][phpAds_actionActivationMailed] = "Notificación de activación de la campaña {id} enviada por e-mail";
?>
